/**
 * Checks if a given HTML element has a slot with the specified name or any slots if no name is provided.
 *
 * @param {HTMLElement} element - The HTML element to check for slots.
 * @param {string} [name] - The optional name of the slot to search for.
 * @return {boolean} Returns true if the element contains a slot with the specified name, or any slot if no name is provided; otherwise, false.
 */
function hasSlot(element, name) {
    if (name) {
        return element.querySelector(`[slot="${name}"]`) !== null;
    }
    // Text nodes are not considered as children
    return element.children.length > 0 || !!element.textContent;
}
function slotDecoratorFactory(slotName, elementPropertyKey, accessor) {
    return (target, propertyKey) => {
        Object.defineProperty(target, propertyKey, {
            get() {
                const host = this[elementPropertyKey];
                if (!host) {
                    throw Error(`@Slot('${slotName}'): '${elementPropertyKey}' property is not defined. You must declare '@Element() ${elementPropertyKey}: HTMLElement;' in your component.`);
                }
                return accessor(host);
            },
            configurable: true,
            enumerable: true,
        });
    };
}
/**
 * A property decorator that creates a getter for accessing a slotted element within a component.
 *
 * This decorator allows easy access to elements that have been assigned to a specific slot
 * within a web component. It creates a getter that returns the first element matching the specified
 * slot name from the component's DOM.
 *
 * @param slotName - The name of the slot to query for (will be used in the selector '[slot="slotName"]')
 *
 * @param [elementPropertyKey='el'] - The property key of the host element in the component class
 *                            (this property must be decorated with '@Element()' in Stencil components)
 *
 * @example
 * ```tsx
 * @Component({
 *   tag: 'my-component',
 *   shadow: true
 * })
 * export class MyComponent {
 *   // The host element reference
 *   @Element() el: HTMLElement;
 *
 *   // This creates a getter for the header slot
 *   @Slot('header', 'el') header: HTMLElement;
 *
 *   render() {
 *     // Access the slotted header element directly
 *     if (this.header) {
 *       console.log('Header element found:', this.header);
 *     }
 *
 *     return (
 *       <div>
 *         <slot name="header"></slot>
 *         <div class="content">
 *           <slot></slot>
 *         </div>
 *       </div>
 *     );
 *   }
 * }
 * ```
 *
 * @returns A property decorator function that defines a getter on the target component class
 * @throws Error if the specified element property is not defined on the component
 */
function Slot(slotName, elementPropertyKey = 'el') {
    return slotDecoratorFactory(slotName, elementPropertyKey, host => host.querySelector(`[slot="${slotName}"]`));
}

export { Slot as S, hasSlot as h };

//# sourceMappingURL=p-0306c092.js.map