import { version } from "../package.json";
import { checkStoryFile, generateFollowUpContent, generateMetaContent, generateStoryContent, registerHandlebarsHelpers, writeFollowUpFile, writeMetaFile, writeStoryFile, } from "./scripts/file";
export const generateStorybookDocs = async (docs) => {
    registerHandlebarsHelpers();
    const unreleasedNew = [];
    const unreleasedUpdated = [];
    const versionNew = [];
    const versionUpdated = [];
    for (const component of docs.components) {
        const parameters = generateParameters(component);
        const metaContent = await generateMetaContent({
            parameters,
            argTypes: generateArgTypes(component),
        });
        await writeMetaFile(component, metaContent);
        const names = getNames(component);
        const storyId = getStoryId(names.storyTitle);
        switch (parameters.docs.since) {
            case 'UNRELEASED':
                unreleasedNew.push(storyId);
                break;
            case version:
                versionNew.push(storyId);
                break;
        }
        switch (parameters.docs.lastModified) {
            case 'UNRELEASED':
                unreleasedUpdated.push(storyId);
                break;
            case version:
                versionUpdated.push(storyId);
                break;
        }
        if (process.env.GITHUB_ACTIONS) {
            continue;
        }
        const storyFileExists = await checkStoryFile(component);
        if (!storyFileExists) {
            const storyContent = await generateStoryContent(Object.assign(Object.assign({}, names), { tag: component.tag }));
            await writeStoryFile(component, storyContent);
        }
    }
    const followUpContent = await generateFollowUpContent({
        storyStatus: {
            new: unreleasedNew.length ? unreleasedNew : versionNew,
            updated: unreleasedUpdated.length ? unreleasedUpdated : versionUpdated,
        },
    });
    await writeFollowUpFile(followUpContent);
};
const generateParameters = (component) => {
    const parameters = { docs: {} };
    if (component.docs) {
        parameters.docs.description = {
            component: component.docs,
        };
    }
    for (const docTag of component.docsTags) {
        if (docTag.name === 'since') {
            parameters.docs.since = docTag.text;
        }
        if (docTag.name === 'deprecated') {
            parameters.docs.until = docTag.text;
        }
        if (docTag.name === 'lastmodified') {
            parameters.docs.lastModified = docTag.text;
        }
    }
    return parameters;
};
const generateArgTypes = (component) => {
    var _a, _b, _c, _d;
    const argTypes = {};
    for (const slot of component.slots) {
        argTypes[slot.name] = {
            description: slot.docs,
            control: false,
            table: {
                category: 'Slots',
                type: {
                    summary: 'HTMLElement',
                },
            },
        };
    }
    for (const event of component.events) {
        argTypes[event.event] = {
            description: event.docs,
            control: false,
            table: {
                category: 'Events',
                type: {
                    summary: (_b = (_a = event.complexType) === null || _a === void 0 ? void 0 : _a.resolved) !== null && _b !== void 0 ? _b : '',
                },
            },
        };
    }
    for (const prop of component.props) {
        const types = getTypes(prop.values);
        const options = getOptions(prop.values);
        argTypes[prop.name] = {
            description: prop.docs,
            options,
            control: {
                type: getControlType(types, options),
            },
            table: {
                category: 'Properties',
                type: {
                    summary: (_d = (_c = prop.complexType) === null || _c === void 0 ? void 0 : _c.resolved) !== null && _d !== void 0 ? _d : '',
                },
                defaultValue: {
                    summary: prop.default,
                },
            },
        };
    }
    return argTypes;
};
const getControlType = (types, options) => {
    const filteredTypes = types.filter(type => type !== 'undefined' && type !== 'null');
    if (!filteredTypes.length || filteredTypes.length > 1) {
        return 'object';
    }
    switch (filteredTypes[0]) {
        case 'string':
            if (options.length > 0) {
                return 'select';
            }
            return 'text';
        case 'boolean':
            return 'boolean';
        default:
            console.info(`Unknown type: ${filteredTypes[0]}`);
            return 'object';
    }
};
const getOptions = (values) => {
    return values.map(value => value.value).filter(Boolean);
};
const getTypes = (values) => {
    return Array.from(new Set(values.map(value => value.type).filter(type => type && type !== 'undefined')).values());
};
function getNames(component) {
    const path = component.filePath;
    if (!path) {
        throw new Error('Storybook generation: component dir path is undefined');
    }
    const componentPath = path.replace('src/components/', '').replace(/\.[^/.]+$/, '');
    const storyTitleParts = componentPath.split('/').map(segment => segment.charAt(0).toUpperCase() + segment.slice(1).replace(/[-_]/g, ' '));
    if (storyTitleParts.length > 1) {
        const lastPart = storyTitleParts[storyTitleParts.length - 1];
        let lastFolder = storyTitleParts[storyTitleParts.length - 2];
        if (lastPart.toLowerCase().endsWith(lastFolder.toLowerCase())) {
            storyTitleParts.splice(storyTitleParts.length - 2, 1);
        }
    }
    const kebabCaseComponent = component.tag.replace('nj-', '');
    return {
        storyTitle: storyTitleParts.join('/'),
        className: kebabCaseComponent
            .split('-')
            .map(word => word.charAt(0).toUpperCase() + word.slice(1).toLowerCase())
            .join(''),
        component: kebabCaseComponent,
    };
}
function getStoryId(storyTitle) {
    return storyTitle.replace(/[\s/]+/g, '-').toLowerCase();
}
//# sourceMappingURL=index.js.map
