import { access, ensureFile, readFile, writeFile } from "fs-extra";
import Handlebars from "handlebars";
export function registerHandlebarsHelpers() {
    Handlebars.registerHelper('json', function (context) {
        return JSON.stringify(context, null, 2);
    });
}
/**
 * Asynchronously checks if a story file exists for the given component.
 *
 * @param {JsonDocsComponent} component - The component object containing information used to determine the file path.
 * @return {Promise<boolean>} A promise that resolves to true if the file exists, or false if it does not.
 */
export async function checkStoryFile(component) {
    const filePath = getFilePath(component, 'story');
    try {
        await access(filePath); // If return anything, file exist
        return true;
    }
    catch (_a) {
        return false;
    }
}
/**
 * Generates meta information content for component.
 *
 * @param {MetaTemplateVariables} templateVariables - The variables to populate the template.
 * @return {Promise<string>} A promise that resolves to the populated template content as a string.
 */
export async function generateMetaContent(templateVariables) {
    const template = await getTemplateFile('story-meta.hbs');
    return template(templateVariables);
}
/**
 * Generates content of the story file.
 *
 * @param {MetaTemplateVariables} templateVariables - The variables to populate the template.
 * @return {Promise<string>} A promise that resolves to the populated template content as a string.
 */
export async function generateStoryContent(templateVariables) {
    const template = await getTemplateFile('story.hbs');
    return template(templateVariables);
}
/**
 * Generates content of the follow-up file.
 *
 * @param {MetaTemplateVariables} templateVariables - The variables to populate the template.
 * @return {Promise<string>} A promise that resolves to the populated template content as a string.
 */
export async function generateFollowUpContent(templateVariables) {
    const template = await getTemplateFile('follow-up.hbs');
    return template(templateVariables);
}
/**
 * Writes the provided content to a story file for the given component.
 *
 * @param {JsonDocsComponent} component - The component we need to write file for.
 * @param {string} content - The content to be written into the story file.
 * @return {Promise<void>} A promise that resolves when the file has been successfully written.
 * @throws {Error} If an unexpected error occurs during the file writing process.
 */
export async function writeStoryFile(component, content) {
    const filePath = getFilePath(component, 'story');
    try {
        await ensureFile(filePath);
        await writeFile(filePath, content);
    }
    catch (error) {
        throw new Error('Storybook generation: unexpected error while writing file');
    }
}
/**
 * Writes the provided content to a meta file for the given component.
 *
 * @param {JsonDocsComponent} component - The component we need to write file for.
 * @param {string} content - The content to be written into the meta file.
 * @return {Promise<void>} A promise that resolves when the file has been successfully written.
 * @throws {Error} If an unexpected error occurs during the file writing process.
 */
export async function writeMetaFile(component, content) {
    const filePath = getFilePath(component, 'meta');
    try {
        await ensureFile(filePath);
        await writeFile(filePath, content);
    }
    catch (error) {
        throw new Error('Storybook generation: unexpected error while writing file');
    }
}
/**
 * Writes the provided content to the follow-up file.
 *
 * @param {string} content - The content to be written into the follow-up file.
 * @return {Promise<void>} A promise that resolves when the file has been successfully written.
 * @throws {Error} If an unexpected error occurs during the file writing process.
 */
export async function writeFollowUpFile(content) {
    const filePath = '../../docs/storybook-webcomponents/utils/follow-up.generated.ts';
    try {
        await ensureFile(filePath);
        await writeFile(filePath, content);
    }
    catch (error) {
        throw new Error('Storybook generation: unexpected error while writing file');
    }
}
function getFilePath(component, file = 'story') {
    const path = component.filePath;
    if (!path || !component.fileName) {
        throw new Error('Storybook generation: component path or file name is undefined');
    }
    const folder = path.split('/').slice(2, -1).join('/');
    const fileName = component.fileName.replace('.tsx', file === 'story' ? '.stories.ts' : '.generated-meta.ts');
    return `../../docs/storybook-webcomponents/stories/${folder}/${fileName}`;
}
async function getTemplateFile(file) {
    try {
        const templateFile = await readFile(`storybook-doc-generation/templates/${file}`, 'utf8');
        return Handlebars.compile(templateFile);
    }
    catch (_a) {
        throw new Error('Storybook generation: template not found');
    }
}
//# sourceMappingURL=file.js.map
